import os, sys
import matplotlib.pyplot as plt

# Append root dir of this project to include functionality
sys.path.append(os.path.dirname(os.getcwd()))
import binary_c
from utils.defaults import physics_defaults
from utils.functions import create_arg_string

"""
This script is an example of running a group of binary systems using a loop. For big grids this is not wise, the grid functionality will be built later

I made this script to with the logging of binaryc set to log only one line per system (when a certain requirement is met).

You can either capture the data and print it, or write it to a file
"""

def run_simple_loop_binary():
    # Some simple function with a loop
    # This function assumes a single output line

    m2 = 14.0 # Msun
    separation = 0 # 0 = ignored, use period
    orbital_period = 4530.0 # days
    eccentricity = 0.0
    metallicity = 0.02
    max_evolution_time = 15000
    buffer = ""

    print ("Binary_c grid output:")

    mass_1 = []
    time = []
    initial_m1 = []

    # Set up for loop. Beware: this is only a proof of concept example. big grid should not be run in this way. rather one should use a queueing/threading system. 
    for m1 in range(15, 20): 
        argstring = f"binary_c M_1 {m1} M_2 {m2} separation {separation} orbital_period {orbital_period} eccentricity {eccentricity} metallicity {metallicity} max_evolution_time {max_evolution_time}"
        
        # Get the output string
        output = binary_c.run_binary(argstring)

        # split output on newlines
        for line in output.split('\n'):
            # Example of splitting off certain lines of output
            if line.startswith('TESTLOG_BINARY_POP'):
                value_array = line.split()[1:]
                # print(value_array)

                # Either save the results in arrays or lists
                mass_1.append(value_array[1])
                time.append(value_array[0])
                initial_m1.append(value_array[2])

                # write headers. can be cleaner
                if not os.path.isfile("test_output.txt"):
                    with open("test_output.txt", "a") as f:
                        f.write('time M1 M1_zams\n')

                # Or write them to a file with a file:
                with open("test_output.txt", "a") as myfile:
                    myfile.write(' '.join(value_array[:3])+'\n')

    print('mass1:', mass_1)
    print('zams_mass1:' ,initial_m1)
    print('time:', time)